@@ -1,12 +1,12 @@
 .logit4Pred <-
-function(lm.out, nm, d, my.formula, brief, res.rows,
-         n.vars, n.pred, n.obs, n.keep, digits.d, pre, line,
-         new.data, pred, pred.all, 
-         numeric.all, in.data.frame, X1.new, 
-         X2.new, X3.new, X4.new, X5.new, X6.new,
-         pdf.file, width, height, ...) {
+function(lm.out, nm, d, my_formula, brief, res_rows,
+         n.vars, n.pred, n.obs, n.keep, digits_d, pre, line,
+         new.data, pred, pred_all, 
+         numeric.all, in.data.frame, X1_new, 
+         X2_new, X3_new, X4_new, X5_new, X6_new,
+         pdf_file, width, height, ...) {
 
-  pred.sort <- TRUE  # data must be sorted to find cases close to fitted=0.5
+  pred_sort <- TRUE  # data must be sorted to find cases close to fitted=0.5
 
 # ----------
 # prediction
@@ -16,8 +16,8 @@ function(lm.out, nm, d, my.formula, brief, res.rows,
 
   cat("Data, Fitted Values, Standard Errors\n")
   cat("   [sorted by fitted value]\n")
-  if (n.keep > 50 && pred.all == FALSE && !new.data) 
-    cat("   [to save space only some intervals printed, pred.all=TRUE to see all]\n")
+  if (n.keep > 50 && pred_all == FALSE && !new.data) 
+    cat("   [to save space only some intervals printed, pred_all=TRUE to see all]\n")
   .dash(68)
   
   if (!new.data) {
@@ -38,9 +38,9 @@ function(lm.out, nm, d, my.formula, brief, res.rows,
   }
 
   else {
-    Xnew.val <- list(X1.new)
+    Xnew.val <- list(X1_new)
     if (n.vars > 2) for (i in 2:(n.pred)) {
-      pp <- eval(parse(text=paste("X", toString(i),".new",sep="")))
+      pp <- eval(parse(text=paste("X", toString(i),"_new",sep="")))
       Xnew.val <- c(Xnew.val, list(pp))
     }
     Xnew <- expand.grid(Xnew.val)
@@ -60,21 +60,21 @@ function(lm.out, nm, d, my.formula, brief, res.rows,
   names(out)[n.vars+2] <- "fitted"
   names(out)[n.vars+3] <- "std.err"
   out <- data.frame(out)
-  if (pred.sort) {
+  if (pred_sort) {
     o <- order(out[,n.vars+2])  # fitted value
     out <- out[o,]
   }
 
 
-  if (n.keep < 25  || pred.all == TRUE || new.data)
-    print(out, digits=digits.d)
+  if (n.keep < 25  || pred_all == TRUE || new.data)
+    print(out, digits=digits_d)
   else {
-    print(out[1:4,], digits=digits.d)
+    print(out[1:4,], digits=digits_d)
     cat("\n... for the rows of data where fitted is close to 0.5 ...\n\n")
     i.mid <- which.min(abs(0.5-sort(p.int$fit)))  # requires out is sorted by fit
-    print(out[(i.mid-2):(i.mid+2),], digits=digits.d)
+    print(out[(i.mid-2):(i.mid+2),], digits=digits_d)
     cat("\n... for the last 4 rows of sorted data ...\n\n")
-    print(out[(n.keep-3):n.keep,], digits=digits.d)
+    print(out[(n.keep-3):n.keep,], digits=digits_d)
   }
   .dash(68)
 
@@ -113,9 +113,9 @@ function(lm.out, nm, d, my.formula, brief, res.rows,
 
 
   # graphics
-  if (pred && n.pred==1 && !is.factor(lm.out$model[,nm[2]]) && is.null(X1.new)) {
+  if (pred && n.pred==1 && !is.factor(lm.out$model[,nm[2]]) && is.null(X1_new)) {
 
-    .opendev(pdf.file, width, height)
+    .opendev(pdf_file, width, height)
 
     x.values <- lm.out$model[,nm[2]]
     if (!is.factor(lm.out$model[,nm[1]])) {
@@ -124,24 +124,24 @@ function(lm.out, nm, d, my.formula, brief, res.rows,
     }
     else {
       y.values <- as.numeric(lm.out$model[,nm[1]])
-      min.y <- min(y.values)
+      min_y <- min(y.values)
       y.label <- paste(nm[1], " ",
          "(0=", levels(lm.out$model[,nm[1]])[1], ",",
          " 1=", levels(lm.out$model[,nm[1]])[2], ")", sep="")
       for (i in 1:length(y.values))
-        if (y.values[i] == min.y) y.values[i] <- 0 else y.values[i] <- 1
+        if (y.values[i] == min_y) y.values[i] <- 0 else y.values[i] <- 1
     }
 
-    par(bg=getOption("window.fill"))
+    par(bg=getOption("window_fill"))
 
     # plot
     plot(x.values,y.values, type="n", axes=FALSE, ann=FALSE,
          ylim=c(-.10,1.10), ...)
     usr <- par("usr")
-    rect(usr[1], usr[3], usr[2], usr[4], col=getOption("panel.fill"),
-         border=getOption("panel.color"))
+    rect(usr[1], usr[3], usr[2], usr[4], col=getOption("panel_fill"),
+         border=getOption("panel_color"))
 
-    col.grid <- getOption("grid.x.color")
+    col.grid <- getOption("grid_x_color")
     abline(v=axTicks(1), col=col.grid, lwd=.5)
     abline(h=axTicks(2), col=col.grid, lwd=.5)
 
@@ -150,32 +150,32 @@ function(lm.out, nm, d, my.formula, brief, res.rows,
     main.lab <- "Logistic Fit and Scatterplot"
     sub.lab <- NULL
     .axlabs(nm[2], y.label, main.lab, sub.lab, max.lbl.y=3,
-            cex.lab=getOption("lab.cex"), cex.main=1.0, ...) 
+            cex.lab=getOption("lab_cex"), cex.main=1.0, ...) 
 
-    col.fill <- getOption("pt.fill")
-    col.color <- getOption("pt.color")
-    points(x.values,y.values, pch=21, col=col.color, bg=col.fill, cex=0.8)
-    lines(x.values, p.int$fit, col=col.color, lwd=2)
+    col_fill <- getOption("pt_fill")
+    col_color <- getOption("pt_color")
+    points(x.values,y.values, pch=21, col=col_color, bg=col_fill, cex=0.8)
+    lines(x.values, p.int$fit, col=col_color, lwd=2)
 
-    if (!is.null(pdf.file)) {
+    if (!is.null(pdf_file)) {
       dev.off()
-      .showfile(pdf.file, "fitted values and scatter plot")
+      .showfile(pdf_file, "fitted values and scatter plot")
     }
   }
 
   else {  # scatterplot matrix for multiple regression
     if (numeric.all && in.data.frame) {
 
-      .opendev(pdf.file, width, height)
+      .opendev(pdf_file, width, height)
 
       panel2.smooth <- function (x, y, pch=par("pch"), cex=.9,
-        col.pt=getOption("pt.color"), col.smooth=getOption("col.bar.color"),
+        col.pt=getOption("pt_color"), col.smooth=getOption("col.bar_color"),
         span=2/3, iter=3, ...) 
       {
           usr <- par("usr")          
           rect(usr[1], usr[3], usr[2], usr[4],
-               col=getOption("border.fill"), border=getOption("border.color"))
-          points(x, y, pch=pch, col=col.pt, bg=getOption("pt.fill"), cex=cex)
+               col=getOption("border_fill"), border=getOption("border_color"))
+          points(x, y, pch=pch, col=col.pt, bg=getOption("pt_fill"), cex=cex)
 
           ok <- is.finite(x) & is.finite(y)
           if (any(ok)) 
@@ -183,9 +183,9 @@ function(lm.out, nm, d, my.formula, brief, res.rows,
       }
       pairs(lm.out$model[c(nm)], panel=panel2.smooth)
 
-      if (!is.null(pdf.file)) {
+      if (!is.null(pdf_file)) {
         dev.off()
-        .showfile(pdf.file, "scatter plot matrix")
+        .showfile(pdf_file, "scatter plot matrix")
       }
     }
     else {
