@@ -1,17 +1,17 @@
 .OneGroup  <-
 function(Y, Ynm, mu=NULL, n=NULL, m=NULL, s=NULL, brief, bw1,
-         from.data, conf.level, alternative, digits.d, mmd, msmd,
-         Edesired, paired, graph, xlab, line.chart, show.title,
-         pdf.file, width, height) { 
+         from.data, conf_level, alternative, digits_d, mmd, msmd,
+         Edesired, paired, graph, xlab, line_chart, show_title,
+         pdf_file, width, height, ...) { 
 
-  # get lab.x.cex  lab.y.cex
-  lab.cex <- getOption("lab.cex")
-  lab.x.cex <- getOption("lab.x.cex")
-  lab.x.cex <- ifelse(is.null(lab.x.cex), lab.cex, lab.x.cex)
-  adj <- .RSadj(lab.cex=lab.x.cex); lab.x.cex <- adj$lab.cex
+  # get lab_x_cex  lab_y_cex
+  lab_cex <- getOption("lab_cex")
+  lab_x_cex <- getOption("lab_x_cex")
+  lab_x_cex <- ifelse(is.null(lab_x_cex), lab_cex, lab_x_cex)
+  adj <- .RSadj(lab_cex=lab_x_cex); lab_x_cex <- adj$lab_cex
 
   # get variable labels if exist plus axes labels
-  gl <- .getlabels(xlab=NULL, ylab=xlab, main=NULL, lab.x.cex=lab.x.cex,
+  gl <- .getlabels(xlab=NULL, ylab=xlab, main=NULL, lab_x_cex=lab_x_cex,
                    graph.win=FALSE)  # # graphics window not yet set-up
   x.name <- gl$yn; x.lbl <- gl$yl; x.lab <- gl$yb
   main.lab <- gl$mb
@@ -39,9 +39,9 @@ function(Y, Ynm, mu=NULL, n=NULL, m=NULL, s=NULL, brief, bw1,
     v <- s^2
   }
 
-  clpct <- paste(toString(round((conf.level)*100, 2)), "%", sep="")
+  clpct <- paste(toString(round((conf_level)*100, 2)), "%", sep="")
 
-  dig.smr.d <- ifelse (from.data, digits.d, digits.d - 1)
+  dig.smr.d <- ifelse (from.data, digits_d, digits_d - 1)
 
   if (Ynm != "Y") cat(Ynm,  ": ", sep="")
   if (from.data) cat(" n.miss = ", n.miss, ",  ", sep="") 
@@ -55,7 +55,8 @@ function(Y, Ynm, mu=NULL, n=NULL, m=NULL, s=NULL, brief, bw1,
       cat("\n\n------ Normality Assumption ------\n\n")
       # Normality
       if (n > 30) {
-        cat("Sample mean assumed normal because n>30, so no test needed.", sep="", "\n")
+        cat("Sample mean assumed normal because n>30, so no test needed.",
+            sep="", "\n")
       }
       else {
         cat("Null hypothesis is a normal distribution", sep="")
@@ -63,9 +64,10 @@ function(Y, Ynm, mu=NULL, n=NULL, m=NULL, s=NULL, brief, bw1,
         cat("\n")
         if (n > 2 && n < 5000) {
           nrm1 <- shapiro.test(Y)
-          W.1 <- round(nrm1$statistic,min(4,digits.d+1))
-          p.val1 <- round(nrm1$p.value,min(4,digits.d+1))
-          cat(nrm1$method, ":  W = ", W.1, ",  p-value = ", p.val1, sep="", "\n")
+          W.1 <- round(nrm1$statistic,min(4,digits_d+1))
+          p.val1 <- round(nrm1$p.value,min(4,digits_d+1))
+          cat(nrm1$method, ":  W = ", W.1, ",  p-value = ", p.val1,
+              sep="", "\n")
         }
         else
           cat("Sample size out of range for Shapiro-Wilk normality test.", "\n")
@@ -76,18 +78,20 @@ function(Y, Ynm, mu=NULL, n=NULL, m=NULL, s=NULL, brief, bw1,
   if (!brief) cat("\n\n------ Inference ------\n\n")
 
   # t-test
+  if (alternative == "two_sided") alt <- "two.sided"
+
   if (!is.null(mu)) m.dist <- m - mu
   df <- n - 1
   sterr <- s * sqrt(1/n)
-  if (alternative == "two.sided")
-    tcut <- qt((1-conf.level)/2, df=df, lower.tail=FALSE)
+  if (alternative == "two_sided")
+    tcut <- qt((1-conf_level)/2, df=df, lower.tail=FALSE)
   else if (alternative == "less")
-    tcut <- qt(1-conf.level, df=df, lower.tail=FALSE)
+    tcut <- qt(1-conf_level, df=df, lower.tail=FALSE)
   else if (alternative == "greater")
-    tcut <- qt(1-conf.level, df=df, lower.tail=TRUE)
+    tcut <- qt(1-conf_level, df=df, lower.tail=TRUE)
   if (from.data) {
     if (!is.null(mu)) mu.null <- mu else mu.null <- 0
-    ttest <- t.test(Y, conf.level=conf.level, alternative=alternative, mu=mu.null)
+    ttest <- t.test(Y, conf.level=conf_level, alternative=alt, mu=mu.null)
     df <- ttest$parameter
     lb <- ttest$conf[1]
     ub <- ttest$conf[2]
@@ -96,14 +100,14 @@ function(Y, Ynm, mu=NULL, n=NULL, m=NULL, s=NULL, brief, bw1,
       tvalue <- ttest$statistic
       pvalue <- ttest$p.value
     }
-  }
+  }  # end from.data
   else {
     E <- tcut * sterr
     lb <- m - E
     ub <- m + E
     if (!is.null(mu)) {
       tvalue <- m.dist/sterr
-      if (alternative == "two.sided")
+      if (alternative == "two_sided")
         pvalue <- 2 * pt(abs(tvalue), df=df, lower.tail=FALSE)
       else if (alternative == "less")
         pvalue <- pt(abs(tvalue), df=df, lower.tail=FALSE)
@@ -118,9 +122,11 @@ function(Y, Ynm, mu=NULL, n=NULL, m=NULL, s=NULL, brief, bw1,
   if (!is.null(mu)) {
     cat("Hypothesized Value H0: mu =", mu, "\n")
     txt <- "Hypothesis Test of Mean:  t-value = "
-    cat(txt, .fmt(tvalue,3), ",  df = ", df, ",  p-value = ", .fmt(pvalue,3), sep="", "\n\n")
+    cat(txt, .fmt(tvalue,3), ",  df = ", df, ",  p-value = ", .fmt(pvalue,3),
+        sep="", "\n\n")
   }
-  cat("Margin of Error for ", clpct, " Confidence Level:  ", .fmt(E), sep="", "\n")
+  cat("Margin of Error for ", clpct, " Confidence Level:  ", .fmt(E),
+      sep="", "\n")
   txt <- " Confidence Interval for Mean:  "
   cat(clpct, txt, .fmt(lb), " to ", .fmt(ub), sep="", "\n")
 
@@ -136,7 +142,7 @@ function(Y, Ynm, mu=NULL, n=NULL, m=NULL, s=NULL, brief, bw1,
 
   # needed sample size from Edesired
   if (!is.null(Edesired)) {
-    zcut <- qnorm((1-conf.level)/2)
+    zcut <- qnorm((1-conf_level)/2)
     ns <- ((zcut*s)/Edesired)^2 
     n.needed <- ceiling(1.132*ns + 7.368) 
     cat("\n\n------ Needed Sample Size ------\n\n")
@@ -163,12 +169,12 @@ function(Y, Ynm, mu=NULL, n=NULL, m=NULL, s=NULL, brief, bw1,
     plt.title  <- character(length=0)
     manage.gr <- .graphman()
  
-    if (is.null(pdf.file)) {
+    if (is.null(pdf_file)) {
       if (manage.gr) {
         n.win <- 0
         if (!is.null(mu)) n.win <- n.win + 1
         if (paired) n.win <- n.win + 1
-        if (line.chart) n.win <- n.win + 1
+        if (line_chart) n.win <- n.win + 1
         if (n.win > 0) {
           .graphwin(n.win, width, height)
           i.win <- 2   # start first graphics window on 3
@@ -178,8 +184,8 @@ function(Y, Ynm, mu=NULL, n=NULL, m=NULL, s=NULL, brief, bw1,
       }
     }
 
-    if (line.chart) {
-      if (!is.null(pdf.file))
+    if (line_chart) {
+      if (!is.null(pdf_file))
         pdf(file=paste("LineChart_",Ynm,".pdf",sep=""), width=width, height=height)
 
       if (manage.gr) {
@@ -191,17 +197,17 @@ function(Y, Ynm, mu=NULL, n=NULL, m=NULL, s=NULL, brief, bw1,
       plt.title[plt.i] <- paste("Sequentially Plotted Data for", Ynm)
 
       .lc.main(Y, type=NULL,
-        col.line=getOption("pt.color"), col.area=NULL, col.box="black",
-        col.color=getOption("pt.color"), 
-        col.fill=getOption("bar.fill.ordered"), shape.pts=21,
-        col.bg=getOption("panel.fill"), lab.cex=getOption("lab.cex"),
-        axis.cex=0.75, col.axis="gray30", rotate.x=0, rotate.y=0, offset=.5,
-        xy.ticks=TRUE, line.width=1.1,
+        col.line=getOption("pt_color"), col.area=NULL, col.box="black",
+        col_color=getOption("pt_color"), 
+        col_fill=getOption("bar_fill_ordered"), shape_pts=21,
+        col.bg=getOption("panel_fill"), lab_cex=getOption("lab_cex"),
+        axis_cex=0.75, col.axis="gray30", rotate_x=0, rotate_y=0, offset=.5,
+        xy_ticks=TRUE, line_width=1.1,
         xlab=NULL, ylab=NULL, main=plt.title[plt.i], sub=NULL, cex=NULL,
-        time.start=NULL, time.by=NULL, time.reverse=FALSE,
-        center.line="default", quiet=TRUE)
+        time_start=NULL, time_by=NULL, time_reverse=FALSE,
+        center_line="default", quiet=TRUE)
 
-      if (!is.null(pdf.file)) {
+      if (!is.null(pdf_file)) {
         dev.off()
         .showfile(paste("LineChart_", Ynm, ".pdf", sep=""), paste("line chart of", Ynm))
       }
@@ -219,13 +225,13 @@ function(Y, Ynm, mu=NULL, n=NULL, m=NULL, s=NULL, brief, bw1,
     plt.i <- plt.i + 1
     plt.title[plt.i] <- "One-Group Plot"
 
-    .OneGraph(Y, bw1, Ynm, digits.d, brief,
+    .OneGraph(Y, bw1, Ynm, digits_d, brief,
          n, m, mu, mdiff, s, smd, mmd, msmd,
-         clpct, tvalue, pvalue, ub, lb, x.lab, show.title)
+         clpct, tvalue, pvalue, ub, lb, x.lab, show_title)
 
-      if (!is.null(pdf.file)) {
+      if (!is.null(pdf_file)) {
         dev.off()
-        .showfile(pdf.file, paste("density plot of", Ynm))
+        .showfile(pdf_file, paste("density plot of", Ynm))
       }
     }
 
